from setuptools import setup

setup(
    name='smon_report',
    version="0.0.1",
    author='Seryogin Vyacheslav',
    author_email='vyacheslavseregin21@gmail.com',
    description='An application that takes a data and returns the statistic for driver.',
    packages=['source'],
    license='MIT License',
    readme="README.md",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        'Programming Language :: Python :: 3.9',
    ],
    url='https://git.foxminded.com.ua/foxstudent102022/task-6-report-of-monaco-2018-racing/',

)
